#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 invariant
version:              0.6.4
visibility:           public
id:                   invariant-0.6.4-Eza7cCBe5J32PBA7kuy5H9
key:                  invariant-0.6.4-Eza7cCBe5J32PBA7kuy5H9
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  24324156986bf26585b9a88de351b821
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.6.6/site-local/invariant-0.6.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/invariant-0.6.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/invariant-0.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.4-Eza7cCBe5J32PBA7kuy5H9
depends:
    StateVar-1.2.2-A6sCENWC9xLH02ziP9IDyb array-0.5.6.0 base-4.18.2.1
    bifunctors-5.6.3-GYVQu0XuOpW2CBj3GEXuwG
    comonad-5.0.10-AnFECP5xTVcJl7scIuq3CY containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg ghc-prim-0.10.0
    profunctors-5.6.3-Jq2fpvfvATI5D00GlHvYLI stm-2.5.1.0
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3 transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unordered-containers-0.2.20.1-2pZfUb3hQF1KSawFItMd4V

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

